TxCtx

Struct TxCtx 

pub struct TxCtx<D, H, CA>
where D: DB + for<'iter> DBIter<'iter>, H: StorageHasher,
{
Show 15 fields pub write_log: HostRef<RwAccess, WriteLog>, pub in_mem: HostRef<RoAccess, InMemory<H>>, pub db: HostRef<RoAccess, D>, pub iterators: HostRef<RwAccess, PrefixIterators<'static, D>>, pub gas_meter: HostRef<RoAccess, RefCell<GasMeter<TxGasMeter>>>, pub sentinel: HostRef<RoAccess, RefCell<TxSentinel>>, pub wrapper_hash: HostRef<RoAccess, Hash>, pub tx: HostRef<RoAccess, Tx>, pub cmt: HostRef<RoAccess, TxCommitments>, pub tx_index: HostRef<RoAccess, TxIndex>, pub verifiers: HostRef<RwAccess, BTreeSet<Address>>, pub result_buffer: HostRef<RwAccess, Option<Vec<u8>>>, pub yielded_value: HostRef<RwAccess, Option<Vec<u8>>>, pub vp_wasm_cache: HostRef<RwAccess, VpCache<CA>>, pub tx_wasm_cache: HostRef<RwAccess, TxCache<CA>>,
}
A transaction’s host context

Fields

write_log: HostRef<RwAccess, WriteLog>

Mutable access to write log.

in_mem: HostRef<RoAccess, InMemory<H>>

Read-only access to in-memory state.

db: HostRef<RoAccess, D>

Read-only access to DB.

iterators: HostRef<RwAccess, PrefixIterators<'static, D>>

Storage prefix iterators.

gas_meter: HostRef<RoAccess, RefCell<GasMeter<TxGasMeter>>>

Transaction gas meter. In RefCell to charge gas in read-only fns.

sentinel: HostRef<RoAccess, RefCell<TxSentinel>>

Transaction sentinel. In RefCell to charge gas in read-only fns.

wrapper_hash: HostRef<RoAccess, Hash>

Hash of the wrapper transaction associated with the current inner tx.

tx: HostRef<RoAccess, Tx>

The transaction code is used for signature verification

cmt: HostRef<RoAccess, TxCommitments>

The commitments inside the transaction

tx_index: HostRef<RoAccess, TxIndex>

The transaction index is used to identify a shielded transaction’s parent

verifiers: HostRef<RwAccess, BTreeSet<Address>>

The verifiers whose validity predicates should be triggered.

result_buffer: HostRef<RwAccess, Option<Vec<u8>>>

Cache for 2-step reads from host environment.

yielded_value: HostRef<RwAccess, Option<Vec<u8>>>

Storage for byte buffer values yielded from the guest.

vp_wasm_cache: HostRef<RwAccess, VpCache<CA>>

VP WASM compilation cache (this is available in tx context, because we’re pre-compiling VPs from tx_init_account)

tx_wasm_cache: HostRef<RwAccess, TxCache<CA>>

Tx WASM compilation cache

Implementations

Source

impl<D, H, CA> TxCtx<D, H, CA>
where D: DB + for<'iter> DBIter<'iter>, H: StorageHasher, CA: WasmCacheAccess,

pub fn state(&self) -> TxHostEnvState<'_, D, H>

Access state from within a tx

pub fn gas_meter_and_sentinel( &self, ) -> (&RefCell<GasMeter<TxGasMeter>>, &RefCell<TxSentinel>)

Use gas meter and sentinel